(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     55924,       1507]
NotebookOptionsPosition[     15444,        596]
NotebookOutlinePosition[     52683,       1408]
CellTagsIndexPosition[     52640,       1405]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Code Generation for a Symbolic Matrix", "Title"],

Cell["\<\
Copyright \[Copyright] MathCore AB 1999-2004\
\>", "Copyright"],

Cell[TextData[{
 "In this notebook we give an example of how ",
 StyleBox["MathCode F90",
  FontSlant->"Italic"],
 " can be used to generate Fortran90 code for efficient computation of a \
large matrix with symbolic entries. The matrix in this case is a Hessian of a \
given function which is an important entity to compute efficiently in for \
example optimization algorithms."
}], "Text"],

Cell[CellGroupData[{

Cell["A Small Exampe", "Section"],

Cell[CellGroupData[{

Cell["An Expression", "Subsection"],

Cell["\<\
We will use the following expression for generating a large matrix with \
symbolic entries.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"expr", "=", 
   FractionBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"y", " ", "z"}], "]"}], "+", 
      RowBox[{"ArcTan", "[", "x", "]"}]}], ")"}], 
    SqrtBox[
     RowBox[{"1", "+", 
      RowBox[{".5", 
       RowBox[{"\[ExponentialE]", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"x", "^", "2"}]}], "-", 
          RowBox[{"y", "^", "2"}]}], ")"}]}]}]}]]]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Function for Computing the Gradient", "Subsection"],

Cell[TextData[{
 StyleBox["Grad",
  FontWeight->"Bold"],
 " computes the gradient of a function w.r.t. a list of variables "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{"To", " ", "avoid", " ", "warnings"}], "*)"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Grad", ";", 
   RowBox[{"On", "[", 
    RowBox[{"General", "::", "spell1"}], "]"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"To", " ", "avoid", " ", "warnings"}], "*)"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Grad", "[", 
   RowBox[{"fcn_", ",", "vars_"}], "]"}], ":=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "#"], "fcn"}], "&"}], ",", "vars"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Grad", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Function for Computing the Hessian", "Subsection"],

Cell[TextData[{
 StyleBox["Hessian",
  FontWeight->"Bold"],
 " computes the Hessian matrix of a function w.r.t. a list of variables. \
HessianMC should be used because Hessian[] already exists in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"HessianMC", "[", 
   RowBox[{"fcn_", ",", "vars_"}], "]"}], ":=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Grad", "[", 
      RowBox[{"#", ",", "vars"}], "]"}], "&"}], ",", 
    RowBox[{"Grad", "[", 
     RowBox[{"fcn", ",", "vars"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"HessianMC", "[", 
  RowBox[{"expr", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Symbolic Matrix", "Subsection"],

Cell[TextData[{
 "We define a function that evaluates the Hessian of a given expression ",
 StyleBox["expr",
  FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SymbolicMatrix", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
   RowBox[{"HessianMC", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell["A numerical evaluation", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SymbolicMatrix", "[", 
   RowBox[{"1.", ",", "2.", ",", "3."}], "]"}], "//", "MatrixForm"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Code Generation", "Subsection"],

Cell[TextData[{
 "Load the ",
 StyleBox["MathCode F90",
  FontSlant->"Italic"],
 " application package"
}], "Text"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<MathCode`\>\"", "]"}]], "Input"],

Cell["SetDirectory[$MCRoot<>\"/DemosF90/CompiledHessian\"];", "Input"],

Cell[TextData[{
 "We need to declare types of the argument and return value of the function \
to be compiled. In this case ",
 "3",
 " real parameters and a real 3",
 StyleBox[" \[Cross] ",
  FontWeight->"Bold"],
 "3 matrix."
}], "Text"],

Cell[BoxData[
 RowBox[{"Declare", "[", 
  RowBox[{
   RowBox[{"SymbolicMatrix", "[", 
    RowBox[{
     RowBox[{"Real", " ", "x_"}], ",", 
     RowBox[{"Real", " ", "y_"}], ",", 
     RowBox[{"Real", " ", "z_"}]}], "]"}], "\[Rule]", 
   RowBox[{"Real", "[", 
    RowBox[{"3", ",", "3"}], "]"}]}], "]"}]], "Input"],

Cell[TextData[{
 "We generate Fortran90 code and compile it to an executable file using the ",
 StyleBox["BuildCode",
  FontWeight->"Bold"],
 " command. The option ",
 StyleBox["EvaluateFunctions",
  FontWeight->"Bold"],
 " makes optimizations such as common subexpression eliminations and symbolic \
evaluation of the function ",
 StyleBox["SymbolicMatrix",
  FontWeight->"Bold"],
 " before code generation."
}], "Text"],

Cell[BoxData[
 RowBox[{"BuildCode", "[", 
  RowBox[{"EvaluateFunctions", "\[Rule]", 
   RowBox[{"{", "SymbolicMatrix", "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Connect the executable to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InstallCode", "[", "]"}], ";"}]], "Input"],

Cell["Now the external code is used instead", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SymbolicMatrix", "[", 
   RowBox[{"1.", ",", "2.", ",", "3."}], "]"}], "//", "MatrixForm"}]], "Input"],

Cell[TextData[{
 "Remove the link to the external code (",
 StyleBox["Mathematicas",
  FontSlant->"Italic"],
 " own definition of ",
 StyleBox["SymbolicMatrix",
  FontWeight->"Bold"],
 " is used again)."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"UninstallCode", "[", "]"}], ";"}]], "Input"],

Cell[TextData[{
 "Remove the definition of ",
 StyleBox["SymbolicMatrix",
  FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[
 RowBox[{"Remove", "[", "SymbolicMatrix", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Generated Code", "Subsection"],

Cell[TextData[{
 "Here follows a listing of the generated code. Note the extensive use of \
temporary variables. The option ",
 StyleBox["EvaluateFunctions",
  FontWeight->"Bold"],
 " used above in the ",
 StyleBox["BuildCode",
  FontWeight->"Bold"],
 " command decomposes the large symbolic expression in such a way that common \
subexpressions only are evaluated once and then stored in temporary variables \
to be reused in the numeric evaluation of the rhs of the function. This gives \
extremely efficient code!"
}], "Text"],

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<Global.f90\>\"", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Large Example", "Section"],

Cell[CellGroupData[{

Cell["A New Expression", "Subsection"],

Cell["We now consider an expression with 10 parameters", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"expr", "=", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{"y", " ", "z"}], "]"}], "+", 
       RowBox[{"ArcTan", "[", "x", "]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"Log", "[", 
        RowBox[{"u", " ", "v"}], "]"}]}], ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{".5", "d"}]]}], 
    RowBox[{
     SqrtBox[
      RowBox[{"1", "+", 
       RowBox[{".5", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["x", "2"]}], "-", 
          SuperscriptBox["y", "2"]}]]}]}]], 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SuperscriptBox["v", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "w"}]], "+", 
       SqrtBox[
        RowBox[{"2", "+", 
         RowBox[{"Sinh", "[", 
          RowBox[{"1", "/", "a"}], "]"}], "+", 
         RowBox[{"b", "/", "c"}]}]]}], ")"}]}]]}], ";"}]], "Input"],

Cell[TextData[{
 "We redefine the function that evaluates the Hessian of ",
 StyleBox["expr",
  FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SymbolicMatrix", "[", 
    RowBox[{
    "x_", ",", "y_", ",", "z_", ",", "u_", ",", "v_", ",", "w_", ",", "a_", 
     ",", "b_", ",", "c_", ",", "d_"}], "]"}], "=", 
   RowBox[{"HessianMC", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"{", 
      RowBox[{
      "x", ",", "y", ",", "z", ",", "u", ",", "v", ",", "w", ",", "a", ",", 
       "b", ",", "c", ",", "d"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell["A numerical evaluation", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SymbolicMatrix", "[", 
   RowBox[{
   "1.", ",", "2.", ",", "3.", ",", "4.", ",", "5.", ",", "6.", ",", "7.", 
    ",", "8.", ",", "9.", ",", "10."}], "]"}], "//", "MatrixForm"}]], "Input"],

Cell["\<\
The symbolic form of the matrix occupies approximately 30 pages!\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Code Generation", "Subsection"],

Cell[TextData[{
 "We need to declare types of the argument and returnvalue of the function to \
be compiled. In this case a list of ",
 "10",
 " real parameters and a real 10",
 StyleBox[" \[Cross] ",
  FontWeight->"Bold"],
 "10 matrix."
}], "Text"],

Cell[BoxData[
 RowBox[{"Declare", "[", 
  RowBox[{
   RowBox[{"SymbolicMatrix", "[", 
    RowBox[{
     RowBox[{"Real", " ", "x_"}], ",", 
     RowBox[{"Real", " ", "y_"}], ",", 
     RowBox[{"Real", " ", "z_"}], ",", 
     RowBox[{"Real", " ", "u_"}], ",", 
     RowBox[{"Real", " ", "v_"}], ",", 
     RowBox[{"Real", " ", "w_"}], ",", 
     RowBox[{"Real", " ", "a_"}], ",", 
     RowBox[{"Real", " ", "b_"}], ",", 
     RowBox[{"Real", " ", "c_"}], ",", 
     RowBox[{"Real", " ", "d_"}]}], "]"}], "\[Rule]", 
   RowBox[{"Real", "[", 
    RowBox[{"10", ",", "10"}], "]"}]}], "]"}]], "Input"],

Cell[TextData[{
 "We generate Fortran90 code and compile it to an executable file using the ",
 StyleBox["BuildCode",
  FontWeight->"Bold"],
 " command. The option ",
 StyleBox["EvaluateFunctions",
  FontWeight->"Bold"],
 " makes optimiizations such as common subexpression eliminations and \
symbolic evaluation of the function ",
 StyleBox["SymbolicMatrix",
  FontWeight->"Bold"],
 " before code generation."
}], "Text"],

Cell[BoxData[
 RowBox[{"BuildCode", "[", 
  RowBox[{"EvaluateFunctions", "\[Rule]", 
   RowBox[{"{", "SymbolicMatrix", "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Connect the executable to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InstallCode", "[", "]"}], ";"}]], "Input"],

Cell["Now the external code is used instead", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SymbolicMatrix", "[", 
   RowBox[{
   "1.", ",", "2.", ",", "3.", ",", "4.", ",", "5.", ",", "6.", ",", "7.", 
    ",", "8.", ",", "9.", ",", "10."}], "]"}], "//", "MatrixForm"}]], "Input"],

Cell[TextData[{
 "Remove the link to the external code (",
 StyleBox["Mathematicas",
  FontSlant->"Italic"],
 " own definition of ",
 StyleBox["SymbolicMatrix",
  FontWeight->"Bold"],
 " is used again)."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"UninstallCode", "[", "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Performance Comparision", "Subsection"],

Cell[TextData[{
 "To compare performance between compiled and uncompiled code we define a \
function that uses ",
 StyleBox["SymbolicMatrix",
  FontWeight->"Bold"],
 " a specified number of times."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RepeatComputation", "[", 
    RowBox[{"Integer", " ", "n_"}], "]"}], "\[Rule]", "Null"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Real", "[", 
       RowBox[{"10", ",", "10"}], "]"}], " ", "t"}], "}"}], ",", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"t", "=", 
        RowBox[{"SymbolicMatrix", "[", 
         RowBox[{
          RowBox[{"1.", "+", 
           RowBox[{"1", "/", "n"}]}], ",", 
          RowBox[{"2.", "+", 
           RowBox[{"1", "/", "n"}]}], ",", 
          RowBox[{"3.", "+", 
           RowBox[{"1", "/", "n"}]}], ",", 
          RowBox[{"4.", "+", 
           RowBox[{"1", "/", "n"}]}], ",", 
          RowBox[{"5.", "+", 
           RowBox[{"1", "/", "n"}]}], ",", 
          RowBox[{"6.", "+", 
           RowBox[{"1", "/", "n"}]}], ",", 
          RowBox[{"7.", "+", 
           RowBox[{"1", "/", "n"}]}], ",", 
          RowBox[{"8.", "+", 
           RowBox[{"1", "/", "n"}]}], ",", 
          RowBox[{"9.", "+", 
           RowBox[{"1", "/", "n"}]}], ",", 
          RowBox[{"10.", "+", 
           RowBox[{"1", "/", "n"}]}]}], "]"}]}], ",", 
       RowBox[{"{", "n", "}"}]}], "]"}], ";"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"BuildCode", "[", 
  RowBox[{"EvaluateFunctions", "\[Rule]", 
   RowBox[{"{", "SymbolicMatrix", "}"}]}], "]"}]], "Input"],

Cell["\<\
We do 100 iterations with the uncompiled code and compute the average time:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "100"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"start", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"RepeatComputation", "[", "n", "]"}], ";"}], "\n", 
 RowBox[{"time1", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "]"}], "-", "start"}], ")"}], "/", 
   "n"}]}]}], "Input"],

Cell[TextData[{
 "Install the compiled code into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InstallCode", "[", "]"}], ";"}]], "Input"],

Cell["\<\
We do 100000 iterations with the uncompiled code and compute the average time:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "100000"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"start", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"RepeatComputation", "[", "n", "]"}], ";"}], "\n", 
 RowBox[{"time2", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "]"}], "-", "start"}], ")"}], "/", 
   "n"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"UninstallCode", "[", "]"}], ";"}]], "Input"],

Cell["Speed-up:", "Text"],

Cell[BoxData[
 RowBox[{"time1", "/", "time2"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Clean Up", "Subsection"],

Cell[TextData[{
 "Remove the definition of ",
 StyleBox["SymbolicMatrix",
  FontWeight->"Bold"],
 " and all generated files."
}], "Text"],

Cell[BoxData[
 RowBox[{"Remove", "[", 
  RowBox[{"SymbolicMatrix", ",", "RepeatComputation"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"CleanMathCodeFiles", "[", 
  RowBox[{
   RowBox[{"Confirm", "\[Rule]", "False"}], ",", 
   RowBox[{"CleanAllBut", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{685, 855},
WindowMargins->{{33, Automatic}, {Automatic, 3}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Presentation"], PageWidth -> WindowWidth, 
          ScriptMinSize -> 12, FontSize -> 16], 
         Cell[
          StyleData[All, "Condensed"], PageWidth -> WindowWidth, 
          CellBracketOptions -> {"Margins" -> {1, 1}, "Widths" -> {0, 5}}, 
          ScriptMinSize -> 8, FontSize -> 11], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, ScriptMinSize -> 
          7, FontSize -> 10, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, 
          PageHeaderLines -> {True, True}, 
          PrintingOptions -> {
           "FacingPages" -> True, "FirstPageHeader" -> False}, 
          CellFrameLabelMargins -> 6, StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1, 0}, CounterIncrements -> "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontSize -> 
             34, FontColor -> GrayLevel[1], Background -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{0, 0}, {0, 0}}, LineSpacing -> {1, 0}, FontSize -> 
             44], 
            Cell[
             StyleData["Title", "Condensed"], CellMargins -> {{0, 0}, {0, 0}},
              FontSize -> 20], 
            Cell[
             StyleData["Title", "Printout"], CellMargins -> {{0, 0}, {0, 0}}, 
             FontSize -> 24, FontTracking -> "Plain", Background -> 
             GrayLevel[0]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1, 3}, ParagraphIndent -> -96, CounterIncrements -> 
             "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 18, FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.2, 0.700008, 0.700008]], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{0, 0}, {0, 0}}, LineSpacing -> {1, 6}, 
             ParagraphIndent -> -157, FontSize -> 30], 
            Cell[
             StyleData["Subtitle", "Condensed"], 
             CellMargins -> {{0, 0}, {0, 0}}, ParagraphIndent -> -78, 
             FontSize -> 14], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{0, 0}, {0, 0}}, ParagraphIndent -> -85, 
             FontSize -> 16, Background -> GrayLevel[0.6]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {30, 10}}, PageBreakBelow -> False, 
             CounterIncrements -> "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 14, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{8, 10}, {40, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Subsubtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {12, 8}}, FontSize -> 12], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{9, 10}, {50, 10}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{6, 0}, {0, 1}}, CellDingbat -> 
             None, CellMargins -> {{12, Inherited}, {4, 24}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> 6, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> "Bold", 
             FontColor -> RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellMargins -> {{10, 10}, {8, 32}}, LineSpacing -> {1, 2}, 
             FontSize -> 24, FontTracking -> "Condensed"], 
            Cell[
             StyleData["Section", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{9, 0}, {2, 50}}, FontSize -> 14, FontTracking -> 
             "Plain", FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], 
             CellMargins -> {{12, Inherited}, {8, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{11, 10}, {8, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Subsection", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{9, 0}, {4, 40}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{25, Inherited}, {8, 12}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Times", FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{29, 10}, {8, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Subsubsection", "Condensed"], 
             CellMargins -> {{22, Inherited}, {2, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{21, 0}, {4, 20}}, FontSize -> 11]}, Open]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{12, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 12}, 
             CounterIncrements -> "Text", FontFamily -> "Times"], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{13, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Text", "Condensed"], CellMargins -> {{8, 10}, {4, 4}},
              LineSpacing -> {1, 1}, ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{9, 0}, {4, 4}}, 
             ParagraphSpacing -> {0, 6}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], CellMargins -> {{12, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 6}, 
             CounterIncrements -> "SmallText", FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{13, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["SmallText", "Condensed"], 
             CellMargins -> {{8, 10}, {2, 2}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{9, 0}, {4, 4}}, FontSize -> 7]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{5, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontWeight -> "Bold", Background -> 
             RGBColor[1, 1, 0]], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{62, Inherited}, {10, 10}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Input", "Condensed"], 
             CellMargins -> {{40, 10}, {4, 4}}], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{44, 0}, {6, 6}},
              Background -> GrayLevel[0.8]]}, Closed]], 
         Cell[
          StyleData["InlineInput"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, PageBreakWithin -> 
          False, GroupPageBreakWithin -> False, DefaultFormatType -> 
          DefaultInputFormatType, AutoItalicWords -> {}, FormatType -> 
          InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
          CounterIncrements -> "Input", FontWeight -> "Bold"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, CellEditDuplicate -> True, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, 
             CellLabelMargins -> {{3, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Output", Background -> 
             RGBColor[1, 0.900008, 0.900008]], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{62, Inherited}, {12, 5}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Output", "Condensed"], 
             CellMargins -> {{40, Inherited}, {4, 1}}], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{44, 0}, {6, 2}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Message", StyleMenuListing -> 
             None, FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Message", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Message", "Condensed"], 
             CellMargins -> {{50, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Print", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Print", "Condensed"], 
             CellMargins -> {{50, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Graphics", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Graphics", "Condensed"], 
             CellMargins -> {{52, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {175, 175}], 
            Cell[
             StyleData["Graphics", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {250, 250}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 11, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "Condensed"], FontSize -> 8], 
            Cell[
             StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Unique Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Author"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {2, 10}}, FontSize -> 16, FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["Author", "Presentation"], 
             CellMargins -> {{12, 10}, {2, 12}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}, FontSize -> 20], 
            Cell[
             StyleData["Author", "Condensed"], 
             CellMargins -> {{8, 10}, {1, 4}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}, FontSize -> 12], 
            Cell[
             StyleData["Author", "Printout"], 
             CellMargins -> {{9, 0}, {4, 12}}, ParagraphSpacing -> {0, 6}, 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Copyright"], ShowCellBracket -> False, 
             CellMargins -> {{10, 10}, {40, 2}}, FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["Copyright", "Presentation"], 
             CellMargins -> {{12, 10}, {50, 2}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["Copyright", "Condensed"], 
             CellMargins -> {{8, 10}, {12, 1}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["Copyright", "Printout"], 
             CellMargins -> {{9, 0}, {72, 4}}, FontSize -> 7]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Example"], CellMargins -> {{12, 10}, {5, 12}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 12}, 
             CounterIncrements -> "Example", FontFamily -> "Times", 
             FontWeight -> "Bold"], 
            Cell[
             StyleData["Example", "Presentation"], 
             CellMargins -> {{18, 10}, {8, 20}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Example", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 8}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["Example", "Printout"], 
             CellMargins -> {{9, 0}, {4, 10}}, ParagraphSpacing -> {0, 6}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Definition"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             ShowStringCharacters -> True, CounterIncrements -> "Definition", 
             FontFamily -> "Helvetica", FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> RGBColor[0.2, 0.700008, 0.700008]], 
            Cell[
             StyleData["Definition", "Presentation"], 
             CellMargins -> {{62, Inherited}, {5, 12}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Definition", "Condensed"], 
             CellMargins -> {{40, 10}, {1, 4}}], 
            Cell[
             StyleData["Definition", "Printout"], 
             CellMargins -> {{44, 0}, {2, 6}}, Background -> GrayLevel[0.6]]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Theorem"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             ShowStringCharacters -> True, CounterIncrements -> "Theorem", 
             FontFamily -> "Helvetica", FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Theorem", "Presentation"], 
             CellMargins -> {{62, Inherited}, {5, 12}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Theorem", "Condensed"], 
             CellMargins -> {{40, 10}, {1, 4}}], 
            Cell[
             StyleData["Theorem", "Printout"], 
             CellMargins -> {{44, 0}, {2, 6}}, Background -> GrayLevel[0.4]]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseMain"], CellFrame -> {{6, 0}, {0, 1}}, 
             CellMargins -> {{12, Inherited}, {4, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameColor -> RGBColor[0.571389, 0.19675, 0.570504], 
             CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 16, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["ExerciseMain", "Presentation"], 
             CellMargins -> {{18, 10}, {8, 32}}, LineSpacing -> {1, 2}, 
             FontSize -> 24, FontTracking -> "Condensed"], 
            Cell[
             StyleData["ExerciseMain", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["ExerciseMain", "Printout"], 
             CellMargins -> {{9, 0}, {2, 50}}, CellFrameColor -> 
             GrayLevel[0.500008], FontSize -> 14, FontTracking -> "Plain", 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Exercise"], CellDingbat -> "\[FilledDownTriangle]", 
             CellMargins -> {{23, Inherited}, {4, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Times", FontSize -> 13, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Exercise", "Presentation"], 
             CellMargins -> {{33, 10}, {8, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Exercise", "Condensed"], 
             CellMargins -> {{17, Inherited}, {2, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Exercise", "Printout"], 
             CellFrame -> {{0, 0}, {0.5, 0}}, CellDingbat -> None, 
             CellMargins -> {{9, 0}, {6, 20}}, FontSize -> 11, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseText"], CellMargins -> {{62, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterIncrements -> "ExcersiceText", FontFamily -> "Times"], 
            Cell[
             StyleData["ExerciseText", "Presentation"], 
             CellMargins -> {{74, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["ExerciseText", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 2}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["ExerciseText", "Printout"], 
             CellMargins -> {{54, 0}, {4, 4}}, ParagraphSpacing -> {0, 6}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Itemize"], CellDingbat -> "\[FilledSmallCircle]", 
             CellMargins -> {{65, Inherited}, {8, 8}}, FontFamily -> "Times", 
             FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Itemize", "Presentation"], 
             CellMargins -> {{Inherited, 10}, {8, 12}}, LineSpacing -> {1, 0},
              FontSize -> 18], 
            Cell[
             StyleData["Itemize", "Condensed"], 
             CellMargins -> {{Inherited, Inherited}, {2, 12}}, FontSize -> 
             10], 
            Cell[
             StyleData["Itemize", "Printout"], 
             CellMargins -> {{Inherited, 0}, {4, 20}}, FontSize -> 11]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayCode"], CellFrame -> 2, 
             CellMargins -> {{52, 10}, {8, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> True, 
             CellLabelMargins -> {{5, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             FontWeight -> "Bold", Background -> RGBColor[1, 1, 0]], 
            Cell[
             StyleData["DisplayCode", "Presentation"], 
             CellMargins -> {{62, Inherited}, {10, 10}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["DisplayCode", "Condensed"], 
             CellMargins -> {{40, 10}, {4, 4}}], 
            Cell[
             StyleData["DisplayCode", "Printout"], 
             CellMargins -> {{44, 0}, {6, 6}}, Background -> GrayLevel[0.8]]},
            Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], CellMargins -> {{62, 10}, {2, 10}}, 
             CellHorizontalScrolling -> True, ScriptLevel -> 0, 
             SingleLetterItalics -> True, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{74, 10}, {2, 10}}, FontSize -> 18], 
            Cell[
             StyleData["DisplayFormula", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["DisplayFormula", "Printout"], 
             CellMargins -> {{54, 10}, {2, 10}}, FontSize -> 10]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChemicalFormula"], CellMargins -> {{62, 10}, {2, 10}},
              AutoSpacing -> False, ScriptBaselineShifts -> {0.6, Automatic}, 
             ScriptLevel -> 1, SingleLetterItalics -> False, ZeroWidthTimes -> 
             True], 
            Cell[
             StyleData["ChemicalFormula", "Presentation"], 
             CellMargins -> {{74, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Printout"], 
             CellMargins -> {{54, 10}, {2, 10}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], CellMargins -> {{12, 10}, {Inherited, 6}}, 
             FontFamily -> "Courier"], 
            Cell[
             StyleData["Program", "Presentation"], 
             CellMargins -> {{13, 30}, {Inherited, 4}}, FontSize -> 9.5], 
            Cell[
             StyleData["Program", "Condensed"], 
             CellMargins -> {{8, 10}, {Inherited, 4}}, FontSize -> 9.5], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{9, 0}, {Inherited, 4}}, FontSize -> 9.5]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Automatic Numbering", "Section"], 
         Cell[
         "The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedEquation"], 
             CellMargins -> {{62, 10}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["NumberedEquation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> DefaultInputFormatType, CounterIncrements -> 
             "NumberedEquation", FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedEquation", "Presentation"], 
             CellMargins -> {{74, 10}, {Inherited, Inherited}}], 
            Cell[
             StyleData["NumberedEquation", "Condensed"], 
             CellMargins -> {{52, 10}, {Inherited, Inherited}}], 
            Cell[
             StyleData["NumberedEquation", "Printout"], 
             CellMargins -> {{54, 0}, {Inherited, Inherited}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedFigure"], 
             CellMargins -> {{62, 145}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {
                Cell[
                 TextData[{"Figure ", 
                   CounterBox["NumberedFigure"]}]], None}}, CounterIncrements -> 
             "NumberedFigure", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, 
             FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedFigure", "Presentation"]], 
            Cell[
             StyleData["NumberedFigure", "Condensed"]], 
            Cell[
             StyleData["NumberedFigure", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedTable"], 
             CellMargins -> {{62, 145}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {
                Cell[
                 TextData[{"Table ", 
                   CounterBox["NumberedTable"]}]], None}}, TextAlignment -> 
             Center, CounterIncrements -> "NumberedTable", 
             FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedTable", "Presentation"]], 
            Cell[
             StyleData["NumberedTable", "Condensed"]], 
            Cell[
             StyleData["NumberedTable", "Printout"]]}, Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 9, 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 6], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 9, 
          FontWeight -> "Bold"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"]], 
            Cell[
             StyleData["Hyperlink", "Condensed"]], 
            Cell[
             StyleData["Hyperlink", "Printout"], FontColor -> GrayLevel[0], 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"]], 
            Cell[
             StyleData["MainBookLink", "Condensed"]], 
            Cell[
             StyleData["MainBookLink", "Printout"], FontColor -> GrayLevel[0],
              Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> GrayLevel[1], Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"]], 
            Cell[
             StyleData["AddOnsLink", "Condensed"]], 
            Cell[
             StyleData["AddOnLink", "Printout"], FontColor -> GrayLevel[0], 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> GrayLevel[1], Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuideLink", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"]], 
            Cell[
             StyleData["RefGuideLink", "Condensed"]], 
            Cell[
             StyleData["RefGuideLink", "Printout"], FontColor -> GrayLevel[0],
              Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"]], 
            Cell[
             StyleData["GettingStartedLink", "Condensed"]], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], FontColor -> 
             GrayLevel[0], Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"]], 
            Cell[
             StyleData["OtherInformationLink", "Condensed"]], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], FontColor -> 
             GrayLevel[0], Background -> GrayLevel[1]]}, Closed]]}, Closed]]},
      Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Microsoft Windows (32-bit) (November 7, 2010)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 54, 0, 55, "Title"],
Cell[614, 22, 73, 2, 54, "Copyright"],
Cell[690, 26, 390, 8, 61, "Text"],
Cell[CellGroupData[{
Cell[1105, 38, 33, 0, 54, "Section"],
Cell[CellGroupData[{
Cell[1163, 42, 35, 0, 44, "Subsection"],
Cell[1201, 44, 115, 3, 25, "Text"],
Cell[1319, 49, 495, 17, 69, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1851, 71, 59, 0, 44, "Subsection"],
Cell[1913, 73, 136, 4, 25, "Text"],
Cell[2052, 79, 191, 5, 48, "Input"],
Cell[2246, 86, 213, 6, 48, "Input"],
Cell[2462, 94, 252, 9, 48, "Input"],
Cell[2717, 105, 142, 4, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2896, 114, 58, 0, 44, "Subsection"],
Cell[2957, 116, 265, 8, 43, "Text"],
Cell[3225, 126, 319, 10, 48, "Input"],
Cell[3547, 138, 147, 4, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3731, 147, 39, 0, 44, "Subsection"],
Cell[3773, 149, 142, 4, 25, "Text"],
Cell[3918, 155, 275, 8, 48, "Input"],
Cell[4196, 165, 38, 0, 25, "Text"],
Cell[4237, 167, 137, 3, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4411, 175, 37, 0, 44, "Subsection"],
Cell[4451, 177, 115, 5, 25, "Text"],
Cell[4569, 184, 74, 1, 48, "Input"],
Cell[4646, 187, 70, 0, 48, "Input"],
Cell[4719, 189, 237, 8, 43, "Text"],
Cell[4959, 199, 313, 9, 48, "Input"],
Cell[5275, 210, 421, 12, 61, "Text"],
Cell[5699, 224, 144, 3, 48, "Input"],
Cell[5846, 229, 106, 4, 25, "Text"],
Cell[5955, 235, 77, 2, 48, "Input"],
Cell[6035, 239, 53, 0, 25, "Text"],
Cell[6091, 241, 137, 3, 48, "Input"],
Cell[6231, 246, 215, 8, 25, "Text"],
Cell[6449, 256, 79, 2, 48, "Input"],
Cell[6531, 260, 107, 4, 25, "Text"],
Cell[6641, 266, 72, 1, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6750, 272, 40, 0, 44, "Subsection"],
Cell[6793, 274, 529, 12, 79, "Text"],
Cell[7325, 288, 79, 1, 48, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7453, 295, 34, 0, 54, "Section"],
Cell[CellGroupData[{
Cell[7512, 299, 38, 0, 44, "Subsection"],
Cell[7553, 301, 64, 0, 25, "Text"],
Cell[7620, 303, 1005, 34, 84, "Input"],
Cell[8628, 339, 127, 4, 25, "Text"],
Cell[8758, 345, 448, 12, 69, "Input"],
Cell[9209, 359, 38, 0, 25, "Text"],
Cell[9250, 361, 224, 5, 48, "Input"],
Cell[9477, 368, 88, 2, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9602, 375, 37, 0, 44, "Subsection"],
Cell[9642, 377, 249, 8, 43, "Text"],
Cell[9894, 387, 595, 16, 69, "Input"],
Cell[10492, 405, 422, 12, 61, "Text"],
Cell[10917, 419, 144, 3, 48, "Input"],
Cell[11064, 424, 106, 4, 25, "Text"],
Cell[11173, 430, 77, 2, 48, "Input"],
Cell[11253, 434, 53, 0, 25, "Text"],
Cell[11309, 436, 224, 5, 48, "Input"],
Cell[11536, 443, 215, 8, 25, "Text"],
Cell[11754, 453, 79, 2, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11870, 460, 47, 0, 44, "Subsection"],
Cell[11920, 462, 209, 6, 43, "Text"],
Cell[12132, 470, 1265, 37, 89, "Input"],
Cell[13400, 509, 144, 3, 48, "Input"],
Cell[13547, 514, 99, 2, 25, "Text"],
Cell[13649, 518, 387, 13, 109, "Input"],
Cell[14039, 533, 111, 4, 25, "Text"],
Cell[14153, 539, 77, 2, 48, "Input"],
Cell[14233, 543, 102, 2, 25, "Text"],
Cell[14338, 547, 390, 13, 109, "Input"],
Cell[14731, 562, 79, 2, 48, "Input"],
Cell[14813, 566, 25, 0, 25, "Text"],
Cell[14841, 568, 57, 1, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14935, 574, 30, 0, 44, "Subsection"],
Cell[14968, 576, 137, 5, 25, "Text"],
Cell[15108, 583, 111, 2, 48, "Input"],
Cell[15222, 587, 194, 5, 48, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
